@@ -7,6 +7,7 @@ module Data.Conduit.Pool
     , P.Pool
     , P.createPool
     , P.withResource
+    , withResourceT
     ) where
 
 import qualified Data.Pool as P
@@ -26,6 +27,17 @@ data ManagedResource m a = ManagedResource
     -- pool.
     }
 
+-- | Like 'P.withResource', but uses 'MonadResource' instead of 'MonadBaseControl'.
+--
+-- Since 0.1.1
+withResourceT :: MonadResource m => P.Pool a -> (a -> m b) -> m b
+withResourceT pool f = do
+    mr <- takeResource pool
+    b <- f $ mrValue mr
+    mrReuse mr True
+    mrRelease mr
+    return b
+
 -- | Take a resource from the pool and register a release action.
 takeResource :: MonadResource m => P.Pool a -> m (ManagedResource m a)
 takeResource pool = do
